![build](https://github.com/LedgerInvesting/bayesblend/actions/workflows/python-app.yml/badge.svg)
[![ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![docs](https://readthedocs.org/projects/ledger-investing-bayesblend/badge/?version=latest)](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/?badge=latest)


# BayesBlend

BayesBlend provides an easy-to-use interface to combine predictions from multiple Bayesian models using techniques including (pseudo) Bayesian model averaging, hierarchical stacking, and more!

Check out the [documentation](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/) for:

* The [Getting Started](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/user-guide/getting-started/) guide on using BayesBlend.
* Our [overview](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/user-guide/blending/) of Bayesian model averaging, stacking, hierarchical stacking and blending. 
* How BayesBlend [integrates with Arviz](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/user-guide/arviz/).
* How to [contribute](https://ledger-investing-bayesblend.readthedocs-hosted.com/en/latest/developer-guide/contributing/) to BayesBlend.
